<?php

// Widget class
class Ena_Widget_Horizontal_Scroll extends WP_Widget{

/*-----------------------------------------------------------------------------------*/
/*  Widget Setup
/*-----------------------------------------------------------------------------------*/

 public function __construct() {
    parent::__construct(
      'horizontal_scroll', // Base ID
      __( 'Ena - Post Scroll', 'enamag' ), // Widget Name
      array(
        'classname' => 'widget-hscroll col-double',
        'description' => __( 'Horizontally scrolling posts.', 'enamag' ),
      ),
      array(
        'width' => 250,
      )
    );

  }
/*-----------------------------------------------------------------------------------*/
/*  Display Widget
/*-----------------------------------------------------------------------------------*/

  /**
   * Widget output.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $args
   * @param  array $inst
   */
  public function widget( $args,$inst ){
    extract($args);
        // Background Title Color
        $color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500';
        $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
        $title = apply_filters( 'widget_title', $title, $inst, $this->id_base );
        $cats_id = $nbr_posts = null ;
      if (! empty( $inst['cats_id'] ) ) { $cats_id = esc_attr( $inst['cats_id'] ); }
      if (! empty( $inst['nbr_posts'] ) ) { $nbr_posts = esc_attr( $inst['nbr_posts'] ); }

    echo $before_widget;

    global $post;
    $args = array(
        'numberposts' => $nbr_posts,
        'cat' => $cats_id,
        'offset' => '0'
        );

     $myposts = get_posts( $args ); ?>

    <h4 class="widgetTitle" style="background:<?php echo $color ; ?>!important">

        <?php if ( $title && !empty( $title ) ){ echo '<span>'.$title.'</span>' ;} ?>
         
    </h4>  
    <div class="scrollerWrap widgetBody flexslider scroller_horiz scroller_horiz_<?php echo $this->number; ?>" style="border-color:<?php echo $color.' transparent' ; ?>">
    <ul class="slides">

    <?php foreach ( $myposts as $post ) : setup_postdata( $post );?>
                    
      <li class="scroll-item">
       <span class="scrollerThumbnail ">
         <a href="<?php the_permalink() ?>">
         <?php the_post_thumbnail('enamag-thumb'); ?>
         </a>
         </span>  
         <span class="miniBox-More" >
          <a  style="border:none;border-radius:2px;background:<?php echo $color ?>;padding:5px 20px;color:#fff"  href="<?php the_permalink() ?>"><?php _e('Read More', 'enamag');?></a>
        </span>
      </li>
                  
   <?php 
     endforeach; 
     wp_reset_postdata();
   ?>

    </ul> 
    </div>

    <?php 
    echo $after_widget;

  }

  /**
   * Saves widget settings.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $new_instance
   * @param  array $old_instance
   * @return array
   */
  public function update( $new_instance,$old_instance ){

   $instance = $old_instance;
   $instance['nbr_posts'] = (int)$new_instance['nbr_posts'];
   $instance['cats_id'] = implode(',' , $new_instance['cats_id']  );
   $instance['title'] = esc_sql( strip_tags( $new_instance['title'] ) );
   $instance['background_color'] = $new_instance['background_color'];


    return $instance;
  }

/**
   * Prints the settings form.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $inst
   */
  public function form($inst){
    // Default
    $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
    $nbr_posts = isset( $inst['nbr_posts'] ) ? esc_attr( $inst['nbr_posts'] ) : '10';
    $background_color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500';
    $category = isset( $inst['cats_id'] ) ? esc_attr( $inst['cats_id'] ) : '';
    $cats_id = explode ( ',' , $category ) ;
    $categories_obj = get_categories();
    $categories = array();

    foreach ( $categories_obj as $pn_cat ) {
      $categories[$pn_cat->cat_ID] = $pn_cat->cat_name;
    }
    ?>
    
    <p>
    <label for="<?php echo $this->get_field_id( 'background_color' ); ?>"><?php _e( 'Border Color:', 'enamag' );?><br></label>
      <input class="widefat color-picker" type="text" id="<?php echo $this->get_field_id( 'background_color' ); ?>" name="<?php echo $this->get_field_name( 'background_color' ); ?>" value="<?php echo  $background_color ; ?>" />                            
    </p>

    <p>
      <label for="<?php  echo $this->get_field_id("title") ;?>"><?php _e( 'Title:', 'enamag' ); ?></label>
      <input class="widefat" value="<?php echo $title;?>" name="<?php  echo $this->get_field_name( "title" ) ;?>" type="text" id="<?php  echo $this->get_field_id("title") ;?>"/>
    </p>
    <p>
      <label for="<?php  echo $this->get_field_id( "Cat_id" ) ;?>"><?php _e( 'Select Category:', 'enamag' );?> </label>
      <select class="widefat" multiple="multiple" id="<?php echo $this->get_field_id( 'cats_id' ); ?>[]" name="<?php echo $this->get_field_name( 'cats_id' ); ?>[]">
        
        <?php foreach ( $categories as $key => $option ) { ?>
        
        <option value="<?php echo $key ?>" <?php if ( in_array( $key , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo $option; ?></option>
        
        <?php  } ?>
        
      </select>   
    </p>
    <p>
      <label for="<?php  echo $this->get_field_id( "nbr_posts" ) ;?>"><?php _e( 'Number of posts to show:', 'enamag' ); ?></label>
      <input size="3" value="<?php echo $nbr_posts ;?>" type="text" name="<?php  echo $this->get_field_name( "nbr_posts" ) ;?>" id="<?php  echo $this->get_field_id( "nbr_posts" ) ;?>" />
    </p>

  <?php

   }
}

add_action( 'widgets_init', 'ena_widget_horizontal_scroll' );
function ena_widget_horizontal_scroll() {
  register_widget( 'Ena_Widget_Horizontal_Scroll' );
}
