<?php 

// Widget class
class Ena_Widget_Video extends WP_Widget{

/*-----------------------------------------------------------------------------------*/
/*  Widget Setup
/*-----------------------------------------------------------------------------------*/
  public function __construct() {
    parent::__construct(
      'widget-video', // Base ID
      __( 'Ena - Video', 'enamag' ), // Widget Name
      array(
        'classname' => 'widget-video',
        'description' => __( 'Youtube or vimeo.', 'enamag' ),
      ),
      array(
        'width' => 250,
      )
    );
  }
/*-----------------------------------------------------------------------------------*/
/*  Display Widget
/*-----------------------------------------------------------------------------------*/

  /**
   * Widget output.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $args
   * @param  array $inst
   */
  public function widget( $args, $inst ) {
  	extract( $args );
  	 // Background Title Color
    $color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500';
    $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
	$title = apply_filters( 'widget_title', $title, $inst, $this->id_base );?>

<?php echo $before_widget; ?>

	  <h4 class="widgetTitle" style="background:<?php echo $color ; ?>!important">

  			<?php 
	  			if ( $title && !empty( $title ) ) { 
	  				echo '<span>'.$title.'</span>' ;
	          	}
  			?>

  		</h4>
		<div class="widgetBody embed-responsive embed-responsive-16by9" style="border-color:<?php echo $color.' transparent' ; ?>">

			<?php 
			$video_url = esc_url( $inst['video_url'] );
			if ( strpos( $video_url, 'youtube.com' ) || strpos( $video_url, 'vimeo.com' ) || strpos( $video_url, 'dailymotion.com' ) !== false ):
            echo wp_oembed_get( $video_url );
          else:
            echo __( 'Invalid video URL!', 'enamag' );
          endif;  
		?>

		</div>

		<?php
		echo $after_widget;

			}

/**
	 * Saves widget settings.
	 *
	 * @since  1.0
	 *
	 * @access public
	 * @param  array $new_instance
	 * @param  array $old_instance
	 * @return array
	 */
	public function update( $new_instance,$old_instance ){
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
        $instance['video_url'] = strip_tags($new_instance['video_url']);		
        $instance['background_color'] = $new_instance['background_color'];
		
		return $instance;
	}
	/**
	 * Prints the settings form.
	 *
	 * @since  1.0
	 *
	 * @access public
	 * @param  array $inst
	 */
	public function form( $inst ) {
		// Defaults
		
		$title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
		$video_url = isset( $inst['video_url'] ) ? esc_url( $inst['video_url'] ) : ''; 
        $background_color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500';
?>
	<p>
        <label for="<?php echo $this->get_field_id( 'background_color' ); ?>"><?php _e( 'Border Color:', 'enamag' );?><br></label>
		<input class="color-picker" type="text" id="<?php echo $this->get_field_id( 'background_color' ); ?>" name="<?php echo $this->get_field_name( 'background_color' ); ?>" value="<?php echo  $background_color ; ?>" />                            
	</p>
	<p>
		<label for="<?php echo $this->get_field_id( 'title' ) ?>"><?php _e( 'Title', 'enamag' ) ?></label>
		<input value="<?php echo $title ;?>" type="text" name="<?php echo $this->get_field_name( 'title' ) ?>" id="<?php echo $this->get_field_id( 'title' ) ?>" class="widefat" />
	</p>
	<p>
		<label for="<?php echo $this->get_field_id( 'video_url' ); ?>"><?php _e( 'Video Url', 'enamag' ) ?></label>
		<input type="text" name="<?php echo $this->get_field_name( 'video_url' ) ?>" class="widefat" id="<?php echo $this->get_field_id('video_url'); ?>" value="<?php echo $video_url ;?>" />

	</p>
<?php

	}
}

add_action( 'widgets_init', 'ena_widget_video' );
function ena_widget_video() {
  register_widget( 'Ena_Widget_Video' );
}